<?php
/**
 * Google Maps Element
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! class_exists( 'CyberChimpsGoogleMaps' ) ) {

	class CyberChimpsGoogleMaps {

		protected static $instance;
		public $options;

		/* Static Singleton Factory Method */

		public static function instance() {
			if ( ! isset( self::$instance ) ) {
				$className = __CLASS__;
				self::$instance = new $className;
			}

			return self::$instance;
		} //end of instance

		/**
		 * Initializes plugin variables and sets up WordPress hooks/actions.
		 *
		 * @return void
		 */
		protected function __construct() {
			add_action( 'google_maps', array( $this, 'render_display' ) );
			add_action( 'init', array( $this, 'meta_box' ) );

			$this->options = get_option( 'cyberchimps_options' );
		} //end of construct

		public function render_display() {

			global $post;

			if ( is_page() ) 
			{
				$google_maps_title =	get_post_meta( $post->ID, 'google_maps_title', true );
				$google_maps_embed_iframe =	get_post_meta( $post->ID, 'google_maps_embed_iframe', true );
			}
			else
			{
				$google_maps_title =	$this->options[ 'google_maps_title' ];
				$google_maps_embed_iframe =	$this->options[ 'google_maps_embed_iframe' ];
			}

			?>
				<div id="google_maps_container" class="row-fluid">
					<div id="google_maps" class="span12">
						<div class="googlemaps-content">
							<h2 class="google-maps-title">
								<?php echo $google_maps_title; ?>
							</h2>
							<div class="google-maps-iframe">
								<?php echo $google_maps_embed_iframe; ?>
							</div>
						</div>
					</div>
				</div>
			<?php
		} //end of render_display

		public function meta_box() {
			$page_fields = array(
				array(
					'type' => 'text',
					'id' => 'google_maps_title',
					'std'      => apply_filters('google_maps_title_default','Google Maps'),
					'class' => '',
					'name' => __( 'Maps Title', 'cyberchimps_elements' ),
					'desc' => __( 'Enter google maps title', 'cyberchimps_elements' )
				),
				array(
					'type' => 'editor',
					'settings' => array( 'media_buttons' => true ),
					'id' => 'google_maps_embed_iframe',
					'std' => '<iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d387145.86645180546!2d-74.25820099260999!3d40.70531102328323!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x89c24fa5d33f083b%3A0xc80b8f06e177fe62!2sNew+York%2C+NY%2C+USA!5e0!3m2!1sen!2sin!4v1449467194352" width="600" height="450" frameborder="0" style="border:0" allowfullscreen></iframe>',
					'class' => '',
					'name' => __( 'Map embed iframe', 'cyberchimps_elements' ),
					'desc' => __( 'Go to <a target="_blank" href="https://www.google.com/maps">Google maps.</a> Steps to add: 1) Choose the location 2) Click on menu on top left corner and select "Share or embed map" 3) Select "Embed map" 4) Copy iframe code and paste here', 'cyberchimps_elements' )
				)
			);
			/*
			 * configure your meta box
			 */
			$page_config = array(
				'id' => 'googlemaps_options', // meta box id, unique per meta box
				'title' => __( 'Google Maps', 'cyberchimps_elements' ), // meta box title
				'pages' => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
				'context' => 'normal', // where the meta box appear: normal (default), advanced, side; optional
				'priority' => 'high', // order of meta box: high (default), low; optional
				'fields' => apply_filters( 'cyberchimps_googlemaps_metabox_fields', $page_fields, 'google_maps' ), // list of meta fields (can be added by field arrays)
				'local_images' => false, // Use local or hosted images (meta box images for add/remove)
				'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
			);

			/*
			 * Initiate your meta box
			 */
			$page_meta = new Cyberchimps_Meta_Box( $page_config );
		}

	}
}
CyberChimpsGoogleMaps::instance();
