<?php
/**
 * Element Initializer
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Load style for elements
function cyberchimps_add_elements_scripts() {

	// Set path of library
	$path_lib = get_template_directory_uri() . '/elements/lib/';

	// Add JS for elastislide library to be used for carousel element.
	wp_register_script( 'elastislide', $path_lib . 'js/jquery.elastislide.min.js', array( 'jquery' ), 1, true );
	wp_enqueue_script( 'elastislide' );

	wp_register_style( 'elements_style', $path_lib . 'css/elements.css' );
	wp_enqueue_style( 'elements_style' );

	wp_register_style( 'jcarousel-skin', $path_lib . 'css/jcarousel/skin.css' );
	wp_enqueue_style( 'jcarousel-skin', array( 'bootstrap-responsive-style', 'bootstrap-style' ), '1.0' );

	wp_register_script( 'elements_js', $path_lib . 'js/elements.min.js', array( 'jquery' ), '2013.12.12', true );
	wp_enqueue_script( 'elements_js' );
}

add_action( 'wp_enqueue_scripts', 'cyberchimps_add_elements_scripts', 19 );

// Set path of element folder.
$path_elements = get_template_directory() . '/elements/';

// Load elements
require_once( $path_elements . 'widgets.php' );
require_once( $path_elements . 'breadcrumbs.php' );
require_once( $path_elements . 'callout.php' );
require_once( $path_elements . 'carousel.php' );
require_once( $path_elements . 'htmlbox.php' );
require_once( $path_elements . 'magazine.php' );
require_once( $path_elements . 'pagination.php' );
require_once( $path_elements . 'portfolio.php' );
require_once( $path_elements . 'product.php' );
require_once( $path_elements . 'slider.php' );
require_once( $path_elements . 'twitter-bar.php' );
require_once( $path_elements . 'recent-posts.php' );
require_once( $path_elements . 'boxes.php' );
require_once( $path_elements . 'parallax.php' );
require_once( $path_elements . 'dashboard-widget.php' );
require_once( $path_elements . 'separator.php' );
require_once( $path_elements . 'blank-space.php' );
require_once( $path_elements . 'google-maps.php' );
require_once( $path_elements . 'video.php' );
//require_once( $path_elements . 'profile.php' );
//require_once( $path_elements . 'featured-posts.php' );

// Load shortcodes
require_once( $path_elements . 'shortcodes/init.php' );

function cyberchimps_selected_elements() {
	$options = array(
		'boxes'              => __( 'Boxes', 'cyberchimps_elements' ),
		"callout_section"    => __( 'Callout Section', 'cyberchimps_elements' ),
		"carousel_section"   => __( 'Carousel', 'cyberchimps_elements' ),
		//'featured_posts'		=> __( 'Featured Posts', 'cyberchimps_elements' ),
		'html_box'           => __( 'HTML Box', 'cyberchimps_elements' ),
		'page_slider'        => __( 'CyberChimps Slider', 'cyberchimps_elements' ),
		'magazine'				=> __( 'Magazine', 'cyberchimps_elements' ),
		'portfolio_pro'      => __( 'Portfolio', 'cyberchimps_elements' ),
		"blog_post_page"     => __( 'Post Page', 'cyberchimps_elements' ),
		"product_element"    => __( 'Product', 'cyberchimps_elements' ),
		//"profile"				=> __( 'Profile', 'cyberchimps_elements' ),
		'recent_posts'       => __( 'Recent Posts', 'cyberchimps_elements' ),
		"twitterbar_section" => __( 'Twitter Bar', 'cyberchimps_elements' ),
		"widgets_section"    => __( 'Widgets', 'cyberchimps_elements' ),
		"separator"	     => __( 'Separator', 'cyberchimps_elements'),
		"blank_space"	     => __( 'Blank Space', 'cyberchimps_elements'),
		"google_maps"	     => __( 'Google Maps', 'cyberchimps_elements'),
		"video"	     => __( 'Video', 'cyberchimps_elements')
	);

	return $options;
}

add_filter( 'cyberchimps_elements_draganddrop_options', 'cyberchimps_selected_elements', 2 );

//set defaults elements for page draga and drop
function cyberchimps_selected_page_elements() {
	$options = array(
		'boxes'              => __( 'Boxes', 'cyberchimps_elements' ),
		'breadcrumbs'        => __( 'Breadcrumbs', 'cyberchimps_elements' ),
		"callout_section"    => __( 'Callout Section', 'cyberchimps_elements' ),
		"carousel_section"   => __( 'Carousel', 'cyberchimps_elements' ),
		//'featured_posts'		=> __( 'Featured Posts', 'cyberchimps_elements' ),
		'html_box'           => __( 'HTML Box', 'cyberchimps_elements' ),
		'page_slider'        => __( 'CyberChimps Slider', 'cyberchimps_elements' ),
		'magazine'				=> __( 'Magazine', 'cyberchimps_elements' ),
		'portfolio_pro'      => __( 'Portfolio', 'cyberchimps_elements' ),
		"page_section"       => __( 'Page', 'cyberchimps_elements' ),
		"product_element"    => __( 'Product', 'cyberchimps_elements' ),
		//"profile"				=> __( 'Profile', 'cyberchimps_elements' ),
		'recent_posts'       => __( 'Recent Posts', 'cyberchimps_elements' ),
		"twitterbar_section" => __( 'Twitter Bar', 'cyberchimps_elements' ),
		"widgets_section"    => __( 'Widgets', 'cyberchimps_elements' ),
		"separator"	     => __( 'Separator', 'cyberchimps_elements'),
		"blank_space"	     => __( 'Blank Space', 'cyberchimps_elements'),
		"google_maps"	     => __( 'Google Maps', 'cyberchimps_elements'),
		"video"		=> __( 'Video', 'cyberchimps_elements')
	);

	return $options;
}

add_filter( 'cyberchimps_elements_draganddrop_page_options', 'cyberchimps_selected_page_elements', 2 );

/**  
 *	============ Moved from core/options-medialibrary-uploader.php ===========
 *	============= as register_post_type() is plugin-territory ================
 * Sets up a custom post type to attach image to. This allows us to have
 * individual galleries for different uploaders.
 */
if( !function_exists( 'cyberchimps_mlu_init' ) ) {
	function cyberchimps_mlu_init() {
		register_post_type( 'cybrchmpsthmoption', array(
			'labels'            => array(
				'name' => __( 'Theme Options Media', 'cyberchimps_elements' ),
			),
			'public'            => true,
			'show_ui'           => false,
			'capability_type'   => 'post',
			'hierarchical'      => false,
			'rewrite'           => false,
			'supports'          => array( 'title', 'editor' ),
			'query_var'         => false,
			'can_export'        => true,
			'show_in_nav_menus' => false,
			'public'            => false
		) );
	}
}
add_action( 'admin_init', 'cyberchimps_mlu_init' );
