<?php
/**
 * Product Element.
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Don't load directly
if( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if( !class_exists( 'CyberChimpsProduct' ) ) {
	class CyberChimpsProduct {

		protected static $instance;
		public $location;

		/* Static Singleton Factory Method */
		public static function instance() {
			if( !isset( self::$instance ) ) {
				$className      = __CLASS__;
				self::$instance = new $className;
			}

			return self::$instance;
		}

		/**
		 * Initializes plugin variables and sets up WordPress hooks/actions.
		 *
		 * @return void
		 */
		protected function __construct() {
			// Set location of current page
			add_action( 'product_element', array( $this, 'location' ) );
			// Render the display
			add_action( 'product_element', array( $this, 'render_display' ) );
			add_action( 'init', array( $this, 'page_options' ) );

			add_filter( 'cyberchimps_sections_filter', array( $this, 'blog_options_section' ), 1 );
			add_filter( 'cyberchimps_field_filter', array( $this, 'blog_options' ), 1 );
		}

		/**
		 * Displays product element
		 */
		public function render_display() {
			?>
			<div class="row-fluid" id="cyberchimps_product_container">
				<div class="span12 <?php echo ( $this->layout() == 'left' ) ? 'text-left' : 'text-right'; ?>" id="cyberchimps_product">
					<div class="row-fluid">
						<?php
						if( $this->layout() == 'left' ) {
							$this->text_layout();
							$this->media_layout();
						}
						else {
							$this->media_layout();
							$this->text_layout();
						}
						?>
					</div>
				</div>
			</div>
		<?php
		}

		/**
		 *
		 * Creates new section for the product options
		 *
		 * @param $orig the original array of sections in the blog options
		 *
		 * @return array with the new section added
		 */
		public function blog_options_section( $orig ) {
			$new_section[][4] = array(
				'id'      => 'cyberchimps_product_section',
				'label'   => __( 'Product', 'cyberchimps_elements' ),
				'heading' => 'cyberchimps_blog_heading'
			);

			$new_sections = cyberchimps_array_section_organizer( $orig, $new_section );

			return $new_sections;
		}

		/**
		 * Creates the options to display in the product section
		 *
		 * @param array $orig the original array of options
		 *
		 * @return array with new fields added
		 */
		public function blog_options( $orig ) {

			// Product Layout
			$new_field[][1] = array(
				'name'    => __( 'Product Layout', 'cyberchimps_elements' ),
				'id'      => 'product_layout',
				'std'     => '',
				'type'    => 'select',
				'options' => array(
					'left'  => __( 'Text Left', 'cyberchimps_elements' ),
					'right' => __( 'Text Right', 'cyberchimps_elements' )
				),
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Title
			$new_field[][2] = array(
				'name'    => __( 'Product Title', 'cyberchimps_elements' ),
				'id'      => 'product_title',
				'std'     => __( 'Product', 'cyberchimps_elements' ),
				'type'    => 'text',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Text
			$new_field[][3] = array(
				'name'    => __( 'Product Text', 'cyberchimps_elements' ),
				'id'      => 'product_text',
				'std'     => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. ',
				'type'    => 'editor',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Media Type
			$new_field[][4] = array(
				'name'    => __( 'Media Type', 'cyberchimps_elements' ),
				'id'      => 'product_media_type',
				'class'   => 'select-toggle',
				'std'     => '',
				'type'    => 'select',
				'options' => array(
					'image' => __( 'Image', 'cyberchimps_elements' ),
					'video' => __( 'Video', 'cyberchimps_elements' )
				),
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Image
			$new_field[][5] = array(
				'name'    => __( 'Product Image URL', 'cyberchimps_elements' ),
				'id'      => 'product_image',
				'class'   => 'image-select-toggle',
				'std'     => get_template_directory_uri() . '/elements/lib/images/product/product.jpg',
				'type'    => 'upload',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Video
			$new_field[][6] = array(
				'name'    => __( 'Product Video Embed', 'cyberchimps_elements' ),
				'id'      => 'product_video',
				'class'   => 'video-select-toggle',
				'std'     => '',
				'type'    => 'unfiltered_textarea',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// TODO remove the below it has been replaced by the dropdown beneath it
			// Product Link
//            $new_field[][7] = array(
//                'name'    => __( 'Product Link', 'cyberchimps_elements' ),
//                'id'      => 'product_link',
//                'std'     => 1,
//                'type'    => 'toggle',
//                'section' => 'cyberchimps_product_section',
//                'heading' => 'cyberchimps_blog_heading'
//            );

			// Button image select
			$new_field[][8] = array(
				'type'    => 'select',
				'id'      => 'cyberchimps_product_button',
				'class'   => 'select-hide',
				'name'    => __( 'Product Button Type', 'cyberchimps_elements' ),
				'options' => array( 'no_product_button'    => __( 'No button', 'cyberchimps_elements' ),
				                    'product_button'       => __( 'Button', 'cyberchimps_elements' ),
				                    'product_button_image' => __( 'Button Image', 'cyberchimps_elements' )
				),
				'std'     => 'product_button',

				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product URL
			$new_field[][9] = array(
				'name'    => __( 'Product Button URL', 'cyberchimps_elements' ),
				'id'      => 'product_url',
				'class'   => 'product_button-select',
				'std'     => '',
				'type'    => 'text',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Link Text
			$new_field[][10] = array(
				'name'    => __( 'Product Button Text', 'cyberchimps_elements' ),
				'id'      => 'product_link_text',
				'class'   => 'product_button-select',
				'std'     => __( 'Buy Now', 'cyberchimps_elements' ),
				'type'    => 'text',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Button Image
			$new_field[][11] = array(
				'name'    => __( 'Product Image', 'cyberchimps_elements' ),
				'id'      => 'product_button_image',
				'class'   => 'product_button_image-select',
				'type'    => 'upload',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			// Product Link Text
			$new_field[][12] = array(
				'name'    => __( 'Product Image URL', 'cyberchimps_elements' ),
				'id'      => 'product_button_image_url',
				'class'   => 'product_button_image-select',
				'type'    => 'text',
				'section' => 'cyberchimps_product_section',
				'heading' => 'cyberchimps_blog_heading'
			);

			$new_fields = cyberchimps_array_field_organizer( $orig, $new_field );

			return $new_fields;
		}

		public function page_options() {
			/**
			 * Create Meta boxes on page
			 */

			$directory_uri = get_template_directory_uri();

			$page_fields = array(
				array(
					'type'    => 'select',
					'id'      => 'cyberchimps_product_text_align',
					'class'   => '',
					'name'    => __( 'Product Layout', 'cyberchimps_elements' ),
					'options' => array( 'left'  => __( 'Text Left', 'cyberchimps_elements' ),
					                    'right' => __( 'Text Right',
					                                   'cyberchimps_elements' )
					)
				),
				array(
					'type'  => 'text',
					'id'    => 'cyberchimps_product_title',
					'class' => '',
					'name'  => __( 'Product Title', 'cyberchimps_elements' ),
					'std'   => __( 'Product', 'cyberchimps_elements' )
				),
				array(
					'type'  => 'editor',
					'id'    => 'cyberchimps_product_text',
					'class' => '',
					'name'  => __( 'Product Text', 'cyberchimps_elements' ),
					'std'   => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. '
				),
				array(
					'type'    => 'select',
					'id'      => 'cyberchimps_product_type',
					'class'   => 'select-hide',
					'name'    => __( 'Media Type', 'cyberchimps_elements' ),
					'options' => array( 'image' => __( 'Image', 'cyberchimps_elements' ), 'video' => __( 'Video', 'cyberchimps_elements' ) )
				),
				array(
					'type'  => 'single_image',
					'id'    => 'cyberchimps_product_image',
					'class' => 'image-select',
					'name'  => __( 'Product Image URL', 'cyberchimps_elements' ),
					'std'   => array(
						'url' => $directory_uri . '/elements/lib/images/product/product.jpg',
						'id'  => 'product_image'
					)
				),
				array(
					'type'  => 'unfiltered_textarea',
					'id'    => 'cyberchimps_product_video',
					'class' => 'video-select',
					'name'  => __( 'Product Video Embed', 'cyberchimps_elements' )
				),
//                array(
//                    'type' => 'checkbox',
//                    'id'    => 'cyberchimps_product_link_toggle',
//                    'class' => 'checkbox-toggle',
//                    'name'  => __( 'Product Link', 'cyberchimps_elements' ),
//                    'std'   => 1
//                ),
				array(
					'type'    => 'select',
					'id'      => 'cyberchimps_product_button',
					'class'   => 'select-hide',
					'name'    => __( 'Product Button Type', 'cyberchimps_elements' ),
					'options' => array( 'no_product_button'    => __( 'No button', 'cyberchimps_elements' ),
					                    'product_button'       => __( 'Button', 'cyberchimps_elements' ),
					                    'product_button_image' => __( 'Button Image', 'cyberchimps_elements' )
					),
					'std'     => 'product_button'
				),
				array(
					'type'  => 'text',
					'id'    => 'cyberchimps_product_link_url',
					'class' => 'product_button-select',
					'name'  => __( 'Product URL', 'cyberchimps_elements' ),
					'std'   => home_url()
				),
				array(
					'type'  => 'text',
					'id'    => 'cyberchimps_product_link_text',
					'class' => 'product_button-select',
					'name'  => __( 'Product Link Text', 'cyberchimps_elements' ),
					'std'   => __( 'Buy Now', 'cyberchimps_elements' )
				),
				array(
					'type'  => 'single_image',
					'id'    => 'cyberchimps_product_button_image',
					'class' => 'product_button_image-select',
					'name'  => __( 'Product Button Image', 'cyberchimps_elements' )
				),
				array(
					'type'  => 'text',
					'id'    => 'cyberchimps_product_button_image_link',
					'class' => 'product_button_image-select',
					'name'  => __( 'Product Button Image URL', 'cyberchimps_elements' )
				)

			);
			/*
			 * configure your meta box
			 */
			$page_config = array(
				'id'             => 'product_element_options', // meta box id, unique per meta box
				'title'          => __( 'Product Options', 'cyberchimps_elements' ), // meta box title
				'pages'          => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
				'context'        => 'normal', // where the meta box appear: normal (default), advanced, side; optional
				'priority'       => 'high', // order of meta box: high (default), low; optional
				'fields'         => apply_filters( 'cyberchimps_product_metabox_fields', $page_fields, 'product' ), // list of meta fields (can be added by field arrays)
				'local_images'   => false, // Use local or hosted images (meta box images for add/remove)
				'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
			);

			/*
			 * Initiate your meta box
			 */
			$page_meta = new Cyberchimps_Meta_Box( $page_config );
		}

		/**
		 * Get location of product whether a page or blog
		 *
		 * @return string
		 */
		public function location() {
			$location = ( is_page() ) ? 'page' : 'blog';

			$this->location = $location;
		}

		/**
		 * Return layout information
		 *
		 * @return string left or right
		 */
		protected function layout() {
			global $post;

			if( $this->location == 'page' ) {
				$layout = get_post_meta( $post->ID, 'cyberchimps_product_text_align', true );
			}
			else {
				$layout = cyberchimps_get_option( 'product_layout' );
			}

			return $layout;
		}

		/**
		 * Return product title
		 *
		 * @return string
		 */
		protected function product_title() {
			global $post;

			if( $this->location == 'page' ) {
				$title = get_post_meta( $post->ID, 'cyberchimps_product_title', true );
			}
			else {
				$title = cyberchimps_get_option( 'product_title' );
			}

			return $title;
		}

		/**
		 * Return product text
		 *
		 * @return string
		 */
		protected function product_text() {
			global $post;

			if( $this->location == 'page' ) {
				$text = get_post_meta( $post->ID, 'cyberchimps_product_text', true );
			}
			else {
				$text = cyberchimps_get_option( 'product_text' );
			}

			return $text;
		}

		/**
		 * Return media type
		 *
		 * @return string
		 */
		protected function media_type() {
			global $post;

			if( $this->location == 'page' ) {
				$media = get_post_meta( $post->ID, 'cyberchimps_product_type', true );
			}
			else {
				$media = cyberchimps_get_option( 'product_media_type' );
			}

			return $media;
		}

		/**
		 * Returns image link
		 *
		 * @return string
		 */
		protected function media_image() {
			global $post;

			if( $this->location == 'page' ) {
				$image = get_post_meta( $post->ID, 'cyberchimps_product_image', true );
			}
			else {
				$image = cyberchimps_get_option( 'product_image' );
			}

			return $image;
		}

		/**
		 * Return video script
		 *
		 * @return string
		 */
		protected function media_video() {
			global $post;

			if( $this->location == 'page' ) {
				$video = get_post_meta( $post->ID, 'cyberchimps_product_video', true );
			}
			else {
				$video = cyberchimps_get_option( 'product_video' );
			}

			return $video;
		}

		/**
		 * Returns media layout
		 *
		 * @return string
		 */
		protected function get_media() {
			global $post;

			$media_type = $this->media_type();

			if( $media_type == 'image' ) {
				$content = '<img src="' . $this->media_image() . '" alt=""/>';
			}
			else {
				$content = '<div class="flex-video">' . $this->media_video() . '</div>';
			}

			return $content;
		}

		/**
		 * Returns true or false depending on if link is selected
		 *
		 * @return bool
		 */
		protected function product_link() {
			global $post;

			if( $this->location == 'page' ) {
				$option = get_post_meta( $post->ID, 'cyberchimps_product_button', true );
			}
			else {
				$option = cyberchimps_get_option( 'cyberchimps_product_button' );
			}

			return $option;
		}

		protected function product_button_render() {
			?>
			<div class="cyberchimps-product-link">
				<a class="btn btn-large" id="cyberchimps_product_button" href="<?php echo esc_url( $this->product_url() ); ?>" title="<?php echo esc_attr( $this->product_title() ); ?>">
					<?php echo $this->product_link_text(); ?>
				</a>
			</div>
		<?php
		}

		protected function product_button_image_render() {
			?>
			<div class="cyberchimps-product-link">
				<a class="product-button-image" id="cyberchimps_product_button_image" href="<?php echo esc_url( $this->product_url() ); ?>" title="<?php echo esc_attr( $this->product_title() ); ?>">
					<img src="<?php echo $this->product_button_image(); ?>" alt="<?php echo esc_attr( $this->product_title() ); ?>"/>
				</a>
			</div>
		<?php
		}

		protected function product_button_image() {
			global $post;
			if( $this->location == 'page' ) {
				$image = get_post_meta( $post->ID, 'cyberchimps_product_button_image', true );
			}
			else {
				$image = cyberchimps_get_option( 'product_button_image' );
			}

			return $image;
		}

		/**
		 * Returns link url
		 *
		 * @return string
		 */
		protected function product_url() {
			global $post;

			if( $this->location == 'page' ) {
				if( $this->product_link() == 'product_button' ) {
					$url = get_post_meta( $post->ID, 'cyberchimps_product_link_url', true );
				}
				elseif( $this->product_link() == 'product_button_image' ) {
					$url = get_post_meta( $post->ID, 'cyberchimps_product_button_image_link', true );
				}
			}
			else {
				if( $this->product_link() == 'product_button' ) {
					$url = cyberchimps_get_option( 'product_url' );
				}
				elseif( $this->product_link() == 'product_button_image' ) {
					$url = cyberchimps_get_option( 'product_button_image_url' );
				}
			}

			return $url;
		}

		/**
		 * Returns link text
		 *
		 * @return string
		 */
		protected function product_link_text() {
			global $post;

			if( $this->location == 'page' ) {
				$url = get_post_meta( $post->ID, 'cyberchimps_product_link_text', true );
			}
			else {
				$url = cyberchimps_get_option( 'product_link_text' );
			}

			return $url;
		}

		/**
		 * Display the text layout
		 */
		public function text_layout() {
			?>
			<div class="span6" id="cyberchimps_product_text">
				<h2 class="cyberchimps-product-title">
					<?php echo $this->product_title(); ?>
				</h2>

				<div class="cyberchimps-product-text">
					<?php echo $this->product_text(); ?>
				</div>
				<?php
				if( $this->product_link() == 'product_button' ) {
					$this->product_button_render();
				}
				elseif( $this->product_link() == 'product_button_image' ) {
					$this->product_button_image_render();
				}
				?>

			</div>
		<?php
		}

		/**
		 * Display media layout
		 */
		public function media_layout() {
			?>
			<div class="span6" id="cyberchimps_product_media">
				<?php
				echo $this->get_media();
				?>
			</div>
		<?php
		}
	}
}
CyberChimpsProduct::instance();