<?php
/**
 * Separator Element
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! class_exists( 'CyberChimpsSeparator' ) ) {

	class CyberChimpsSeparator {

		protected static $instance;
		public $options;

		/* Static Singleton Factory Method */

		public static function instance() {
			if ( ! isset( self::$instance ) ) {
				$className = __CLASS__;
				self::$instance = new $className;
			}

			return self::$instance;
		} //end of instance

		/**
		 * Initializes plugin variables and sets up WordPress hooks/actions.
		 *
		 * @return void
		 */
		protected function __construct() {
			add_action( 'separator', array( $this, 'render_display' ) );
			add_action( 'init', array( $this, 'meta_box' ) );

			$this->options = get_option( 'cyberchimps_options' );
		} //end of construct

		public function render_display() {

			global $post;

			if ( is_page() ) 
			{
				$separator_thickness =	get_post_meta( $post->ID, 'separator_thickness', true );
				$separator_color =	get_post_meta( $post->ID, 'separator_color', true );
				$separator_style =	get_post_meta( $post->ID, 'separator_style', true );
			}
			else
			{
				$separator_thickness =	$this->options[ 'separator_thickness' ];
				$separator_color =	$this->options[ 'separator_color' ];
				$separator_style =	$this->options[ 'separator_style' ];
			}
			?>
				<div id="separator_container" class="row-fluid">
					<div id="separator" class="span12">
						<div class="separator-content" style="border-top-width:<?php echo $separator_thickness; ?>px; border-color:<?php echo $separator_color;?>; border-top-style:<?php echo $separator_style; ?>">
						</div>
					</div>
				</div>
			<?php
		} //end of render_display

		public function meta_box() {
			$page_fields = array(
				array(
					'type' => 'text',
					'id' => 'separator_thickness',
					'std'      => apply_filters('separator_thickness_default','5'),
					'class' => '',
					'name' => __( 'Separator', 'cyberchimps_elements' ),
					'desc' => __( 'Enter the thickness of horizontal separator here (in pixels)', 'cyberchimps_elements' )
				),
				array(
					'type' => 'color',
					'id' => 'separator_color',
					'std' => '',
					'class' => '',
					'name' => __( 'Color', 'cyberchimps_elements' ),
					'desc' => __( 'Select color of the separator', 'cyberchimps_elements' )
				),
				array(
					'type' => 'select',
					'id' => 'separator_style',
					'std' => '',
					'class' => '',
					'name' => __( 'Separator style', 'cyberchimps_elements' ),
					'desc' => __( 'Select style of the separator', 'cyberchimps_elements' ),
					'options' => array( 
						        'dashed' => 'Dashed',
						        'dotted' => 'Dotted',
						        'solid' => 'Solid',
						        'double' => 'Double'
						)
				)
			);
			/*
			 * configure your meta box
			 */
			$page_config = array(
				'id' => 'separator_options', // meta box id, unique per meta box
				'title' => __( 'Separator', 'cyberchimps_elements' ), // meta box title
				'pages' => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
				'context' => 'normal', // where the meta box appear: normal (default), advanced, side; optional
				'priority' => 'high', // order of meta box: high (default), low; optional
				'fields' => apply_filters( 'cyberchimps_separator_metabox_fields', $page_fields, 'separator' ), // list of meta fields (can be added by field arrays)
				'local_images' => false, // Use local or hosted images (meta box images for add/remove)
				'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
			);

			/*
			 * Initiate your meta box
			 */
			$page_meta = new Cyberchimps_Meta_Box( $page_config );
		}

	}
}
CyberChimpsSeparator::instance();
