<?php
/**
 * Video Element
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! class_exists( 'CyberChimpsVideo' ) ) {

	class CyberChimpsVideo {

		protected static $instance;
		public $options;

		/* Static Singleton Factory Method */

		public static function instance() {
			if ( ! isset( self::$instance ) ) {
				$className = __CLASS__;
				self::$instance = new $className;
			}

			return self::$instance;
		} //end of instance

		/**
		 * Initializes plugin variables and sets up WordPress hooks/actions.
		 *
		 * @return void
		 */
		protected function __construct() {

			add_action( 'video', array( $this, 'render_display' ) );
			add_action( 'init', array( $this, 'meta_box' ) );

			$this->options = get_option( 'cyberchimps_options' );
		} //end of construct

		public function render_display() {

			global $post;

			if ( is_page() ) 
			{
				$video_link =	get_post_meta( $post->ID, 'video_link', true );
				$video_title =  get_post_meta( $post->ID, 'video_title', true );
			}
			else
			{
				$video_link =	$this->options[ 'video_link' ];
				$video_title =  $this->options[ 'video_title' ];
			}

				$embed_code = wp_oembed_get( $video_link ); 

			?>
				<div id="video_container" class="row-fluid">
					<div id="video-element" class="span12">
						<div class="video-content">
							<h2 class="video-title">
								<?php echo $video_title; ?>
							</h2>
							<div class='flex-video'>
								<?php echo $embed_code; ?>
							</div>
						</div>
					</div>
				</div>
			<?php
		} //end of render_display

		public function meta_box() {
			$page_fields = array(
				array(
					'type' => 'text',
					'id' => 'video_title',
					'std'      => apply_filters('video_title_default','Video title'),
					'class' => '',
					'name' => __( 'Video Title', 'cyberchimps_elements' ),
					'desc' => __( 'Enter the title here', 'cyberchimps_elements' )
				),
				array(
					'type' => 'text',
					'id' => 'video_link',
					'class' => '',
					'std' => 'https://www.youtube.com/watch?v=O5yfVAx3LrM',
					'name' => __( 'Video Link', 'cyberchimps_elements' ),
					'desc' => __( 'Enter the video link here (youtube, vimeo)', 'cyberchimps_elements' )
				)
			);
			/*
			 * configure your meta box
			 */
			$page_config = array(
				'id' => 'video_options', // meta box id, unique per meta box
				'title' => __( 'Video', 'cyberchimps_elements' ), // meta box title
				'pages' => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
				'context' => 'normal', // where the meta box appear: normal (default), advanced, side; optional
				'priority' => 'high', // order of meta box: high (default), low; optional
				'fields' => apply_filters( 'cyberchimps_video_metabox_fields', $page_fields, 'video' ), // list of meta fields (can be added by field arrays)
				'local_images' => false, // Use local or hosted images (meta box images for add/remove)
				'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
			);

			/*
			 * Initiate your meta box
			 */
			$page_meta = new Cyberchimps_Meta_Box( $page_config );
		}

	}
}
CyberChimpsVideo::instance();
